@@ -1,14 +1,16 @@
 from .b_colors import BColors
 from .generate_session import GenerateSession
+from .get_cache_id import GetCacheId
+from .get_cache_peer import GetCachePeer
 from .get_port_server import GetPortServer
-from .get_user_id import GetUserId
 from .run_js import RunJS
 from .spawn_process import SpawnProcess
 
 
 class Core(
     GenerateSession,
-    GetUserId,
+    GetCacheId,
+    GetCachePeer,
     GetPortServer,
     SpawnProcess,
     BColors,
