@@ -2,8 +2,7 @@ import json
 
 from aiohttp import web
 from aiohttp.web_request import BaseRequest
-from pyrogram.raw.functions.phone import EditGroupCallMember
-from pyrogram.raw.types import InputUser
+from pyrogram.raw.functions.phone import EditGroupCallParticipant
 
 
 class ChangeVolumeVoiceCall:
@@ -27,16 +26,16 @@ class ChangeVolumeVoiceCall:
                     )
                 ).full_chat.call
                 await self.pytgcalls._app.send(
-                    EditGroupCallMember(
+                    EditGroupCallParticipant(
                         call=chat_call,
-                        user_id=InputUser(
-                            user_id=self.pytgcalls.get_cache_id(),
-                            access_hash=0,
-                        ),
+                        participant=self.pytgcalls._cache_user_peer[
+                            int(params['chat_id']),
+                        ],
                         muted=False,
                         volume=params['volume'] * 100,
                     ),
                 )
+
                 result_json = {
                     'result': 'OK',
                 }
